@@ -22,20 +22,20 @@ class Algorithm():
 
 
     Attributes:
-        initializer: {function} -- basic function strategy to initialize solution
-        evaluator: {Evaluator} -- evaluator instance in order to obtained fitness (mono or multiple objectives)
-        operators: {[Operator]} -- list of operator to use when launching algorithm
-        policy: {Policy} -- Policy implementation strategy to select operators
+        initialiser: {function} -- basic function strategy to initialise solution
+        evaluator: {:class:`~macop.evaluators.base.Evaluator`} -- evaluator instance in order to obtained fitness (mono or multiple objectives)
+        operators: {[:class:`~macop.operators.base.Operator`]} -- list of operator to use when launching algorithm
+        policy: {:class:`~macop.policies.base.Policy`} -- Policy implementation strategy to select operators
         validator: {function} -- basic function to check if solution is valid or not under some constraints
         maximise: {bool} -- specify kind of optimisation problem 
         verbose: {bool} -- verbose or not information about the algorithm
-        currentSolution: {Solution} -- current solution managed for current evaluation comparison
-        bestSolution: {Solution} -- best solution found so far during running algorithm
-        callbacks: {[Callback]} -- list of Callback class implementation to do some instructions every number of evaluations and `load` when initializing algorithm
-        parent: {Algorithm} -- parent algorithm reference in case of inner Algorithm instance (optional)
+        currentSolution: {:class:`~macop.solutions.base.Solution`} -- current solution managed for current evaluation comparison
+        bestSolution: {:class:`~macop.solutions.base.Solution`} -- best solution found so far during running algorithm
+        callbacks: {[:class:`~macop.callbacks.base.Callback`]} -- list of Callback class implementation to do some instructions every number of evaluations and `load` when initialising algorithm
+        parent: {:class:`~macop.algorithms.base.Algorithm`} -- parent algorithm reference in case of inner Algorithm instance (optional)
     """
     def __init__(self,
-                 initializer,
+                 initialiser,
                  evaluator,
                  operators,
                  policy,
@@ -43,13 +43,27 @@ class Algorithm():
                  maximise=True,
                  parent=None,
                  verbose=True):
+        """Basic Algorithm initialisation
+
+        Args:
+            initialiser: {function} -- basic function strategy to initialise solution
+            evaluator: {:class:`~macop.evaluators.base.Evaluator`} -- evaluator instance in order to obtained fitness (mono or multiple objectives)
+            operators: {[:class:`~macop.operators.base.Operator`]} -- list of operator to use when launching algorithm
+            policy: {:class:`~macop.policies.base.Policy`} -- Policy implementation strategy to select operators
+            validator: {function} -- basic function to check if solution is valid or not under some constraints
+            maximise: {bool} -- specify kind of optimisation problem 
+            parent: {:class:`~macop.algorithms.base.Algorithm`} -- parent algorithm reference in case of inner Algorithm instance (optional)
+            verbose: {bool} -- verbose or not information about the algorithm
+        """
+
+        # public members intialization
+        self.initialiser = initialiser
+        self.evaluator = evaluator
+        self.validator = validator
+        self.policy = policy
 
         # protected members intialization
-        self._initializer = initializer
-        self._evaluator = evaluator
         self._operators = operators
-        self._policy = policy
-        self._validator = validator
         self._callbacks = []
         self._bestSolution = None
         self._currentSolution = None
@@ -75,15 +89,15 @@ class Algorithm():
 
         # also track reference for policy
         if self._parent is not None:
-            self._policy.setAlgo(self.getParent())
+            self.policy.setAlgo(self.getParent())
         else:
-            self._policy.setAlgo(self)
+            self.policy.setAlgo(self)
 
     def addCallback(self, callback):
         """Add new callback to algorithm specifying usefull parameters
 
         Args:
-            callback: {Callback} -- specific Callback instance
+            callback: {:class:`~macop.callbacks.base.Callback`} -- specific Callback instance
         """
         # specify current main algorithm reference for callback
         if self._parent is not None:
@@ -106,7 +120,7 @@ class Algorithm():
         """Recursively find the main parent algorithm attached of the current algorithm
 
         Returns:
-            {Algorithm} -- main algorithm set for this algorithm
+            {:class:`~macop.algorithms.base.Algorithm`}: main algorithm set for this algorithm
         """
 
         current_algorithm = self
@@ -123,19 +137,39 @@ class Algorithm():
         """Set parent algorithm to current algorithm
 
         Args:
-            parent: {Algorithm} -- main algorithm set for this algorithm
+            parent: {:class:`~macop.algorithms.base.Algorithm`} -- main algorithm set for this algorithm
         """
         self._parent = parent
 
+    @property
+    def result(self):
+        """Get the expected result of the current algorithm
+
+        By default the best solution (but can be anything you want)
+
+        Returns:
+            {object}: expected result data of the current algorithm
+        """
+        return self._bestSolution
+
+    @result.setter
+    def result(self, result):
+        """Set current default result of the algorithm
+
+        Args:
+            result: {object} -- expected result data of the current algorithm
+        """
+        self._bestSolution = result
+
     def initRun(self):
         """
-        Initialize the current solution and best solution using the `initialiser` function
+        initialise the current solution and best solution using the `initialiser` function
         """
 
-        self._currentSolution = self._initializer()
+        self._currentSolution = self.initialiser()
 
         # evaluate current solution
-        self._currentSolution.evaluate(self._evaluator)
+        self._currentSolution.evaluate(self.evaluator)
         self.increaseEvaluation()
 
         # keep in memory best known solution (current solution)
@@ -158,7 +192,7 @@ class Algorithm():
         """Get the global number of evaluation (if inner algorithm)
 
         Returns:
-            {int} -- current global number of evaluation
+            {int}: current global number of evaluation
         """
         parent_algorithm = self.getParent()
 
@@ -167,11 +201,27 @@ class Algorithm():
 
         return self._numberOfEvaluations
 
+    def getEvaluation(self):
+        """Get the current number of evaluation
+
+        Returns:
+            {int}: current number of evaluation
+        """
+        return self._numberOfEvaluations
+
+    def setEvaluation(self, evaluations):
+        """Set the current number of evaluation
+
+        Args:
+            evaluations: {int} -- current expected number of evaluation
+        """
+        self._numberOfEvaluations = evaluations
+
     def getGlobalMaxEvaluation(self):
         """Get the global max number of evaluation (if inner algorithm)
 
         Returns:
-            {int} -- current global max number of evaluation
+            {int}: current global max number of evaluation
         """
 
         parent_algorithm = self.getParent()
@@ -198,15 +248,15 @@ class Algorithm():
         Evaluate a solution using evaluator passed when intialize algorithm
 
         Args:
-            solution: {Solution} -- solution to evaluate
+            solution: {:class:`~macop.solutions.base.Solution`} -- solution to evaluate
 
         Returns: 
-            {float} -- fitness score of solution which is not already evaluated or changed
+            {float}: fitness score of solution which is not already evaluated or changed
 
         Note: 
             if multi-objective problem this method can be updated using array of `evaluator`
         """
-        return solution.evaluate(self._evaluator)
+        return solution.evaluate(self.evaluator)
 
     def update(self, solution):
         """
@@ -214,20 +264,20 @@ class Algorithm():
         Check if solution is valid after modification and returns it
         
         Args:
-            solution: {Solution} -- solution to update using current policy
+            solution: {:class:`~macop.solutions.base.Solution`} -- solution to update using current policy
 
         Returns:
-            {Solution} -- updated solution obtained by the selected operator
+            {:class:`~macop.solutions.base.Solution`}: updated solution obtained by the selected operator
         """
 
         # two parameters are sent if specific crossover solution are wished
-        sol = self._policy.apply(solution)
+        sol = self.policy.apply(solution)
 
         # compute fitness of new solution if not already computed
         if sol._score is None:
-            sol.evaluate(self._evaluator)
+            sol.evaluate(self.evaluator)
 
-        if (sol.isValid(self._validator)):
+        if (sol.isValid(self.validator)):
             return sol
         else:
             logging.info("-- New solution is not valid %s" % sol)
@@ -241,20 +291,20 @@ class Algorithm():
         - fitness comparison is done using problem nature (maximising or minimising)
 
         Args:
-            solution: {Solution} -- solution to compare with best one
+            solution: {:class:`~macop.solutions.base.Solution`} -- solution to compare with best one
 
         Returns:
-            {bool} -- `True` if better
+            {bool}:`True` if better
         """
-        if not solution.isValid(self._validator):
+        if not solution.isValid(self.validator):
             return False
 
         # depending of problem to solve (maximizing or minimizing)
         if self._maximise:
-            if solution.fitness() > self._bestSolution.fitness():
+            if solution.fitness > self._bestSolution.fitness:
                 return True
         else:
-            if solution.fitness() < self._bestSolution.fitness():
+            if solution.fitness < self._bestSolution.fitness:
                 return True
 
         # by default
@@ -311,7 +361,7 @@ class Algorithm():
 
     def information(self):
         logging.info(
-            f"-- Best {self._bestSolution} - SCORE {self._bestSolution.fitness()}"
+            f"-- Best {self._bestSolution} - SCORE {self._bestSolution.fitness}"
         )
 
     def __str__(self):
