@@ -10,7 +10,11 @@ from abc import abstractmethod
 class Evaluator():
     """Abstract Evaluator class which enables to compute solution using specific `_data` 
     """
-    def __init__(self, data):
+    def __init__(self, data: dict):
+        """Initialise Evaluator instance which stores into its `_data` dictionary attritute required measures when computing a solution
+        Args:
+            data: {dict} -- specific data dictionnary
+        """
         self._data = data
 
     @abstractmethod
@@ -20,7 +24,7 @@ class Evaluator():
         Fitness is a float value for mono-objective or set of float values if multi-objective evaluation
 
         Args:
-            solution: {Solution} -- Solution instance
+            solution: {:class:`~macop.solutions.base.Solution`} -- Solution instance
 
         Return:
             {float} -- computed solution score (float or set of float if multi-objective evaluation)
@@ -32,6 +36,6 @@ class Evaluator():
            The reason is to better manage evaluator instance if necessary
 
         Args:
-            algo: {Algorithm} -- the algorithm reference runned
+            algo: {:class:`~macop.algorithms.base.Algorithm`} -- the algorithm reference runned
         """
         self._algo = algo
