@@ -8,7 +8,7 @@ from copy import deepcopy
 class Solution():
     """Base abstract solution class structure
     
-    - stores solution data representation into `data` attribute
+    - stores solution data representation into ndarray `data` attribute
     - get size (shape) of specific data representation
     - stores the score of the solution
     """
@@ -17,8 +17,8 @@ class Solution():
         Abstract solution class constructor
 
         Attributes:
-            data: {ndarray} --  array of binary values
-            size: {int} -- size of binary array values
+            data: {ndarray} --  ndarray of values
+            size: {int} -- size of ndarray values
             score: {float} -- fitness score value
         """
         self._data = data
@@ -33,7 +33,7 @@ class Solution():
             validator: {function} -- specific function which validates or not a solution
 
         Returns:
-            {bool} -- `True` is solution is valid
+            {bool}: `True` is solution is valid
         """
         return validator(self)
 
@@ -45,31 +45,56 @@ class Solution():
             _evaluator: {function} -- specific function which computes fitness of solution
 
         Returns:
-            {float} -- fitness score value
+            {float}: fitness score value
         """
         self._score = evaluator.compute(self)
         return self._score
 
+    @property
     def fitness(self):
         """
-        Returns fitness score
+        Returns fitness score (by default `score` private attribute)
 
         Returns:
-            {float} -- fitness score value
+            {float}: fitness score value
         """
         return self._score
 
+    @fitness.setter
+    def fitness(self, score):
+        """
+        Set solution score as wished (by default `score` private attribute)
+        """
+        self._score = score
+
+    @property
+    def data(self):
+        """
+        Returns solution data (by default `data` private attribute)
+
+        Returns:
+            {object}: data values
+        """
+        return self._data
+
+    @data.setter
+    def data(self, data):
+        """
+        Set solution data (by default `data` private attribute)
+        """
+        self._data = data
+
     @staticmethod
     def random(size, validator=None):
         """
-        Initialize solution using random data with validator or not
+        initialise solution using random data with validator or not
 
         Args:
             size: {int} -- expected solution size to generate
             validator: {function} -- specific function which validates or not a solution (if None, not validation is applied)
 
         Returns:
-            {Solution} -- generated solution
+            {:class:`~macop.solutions.base.Solution`}: generated solution
         """
         return None
 
@@ -77,7 +102,7 @@ class Solution():
         """Clone the current solution and its data, but without keeping evaluated `_score`
 
         Returns:
-            {Solution} -- clone of current solution
+            {:class:`~macop.solutions.base.Solution`}: clone of current solution
         """
         copy_solution = deepcopy(self)
         copy_solution._score = None
